polar2grid.utils.legacy\_compat module
======================================

.. automodule:: polar2grid.utils.legacy_compat
   :members:
   :undoc-members:
   :show-inheritance:
   :private-members:
